dwm.c
changeset 1121 898952a1689d
parent 1120 8bd946fbb015
child 1122 6f93af279e0a
--- a/dwm.c	Wed Mar 05 10:22:21 2008 +0000
+++ b/dwm.c	Wed Mar 05 10:31:37 2008 +0000
@@ -44,7 +44,7 @@
  * TODO: Idea:
  * I intend to not provide real Xinerama support, but instead having a Column
  * tilecols[] array which is used by tile(), and a Column maxcols[] arrays which is used by
  * maximise(). Those arrays should be initialized in config.h. For simplicity
  * reasons mwfact should be replaced with a more advanced method which
  * implements the same, but using the boundary between tilecols[0] and
  * tilecols[1] instead. Besides this, get rid of BARPOS and use instead the
@@ -172,7 +172,7 @@
 void manage(Window w, XWindowAttributes *wa);
 void mappingnotify(XEvent *e);
 void maprequest(XEvent *e);
-void maximise(void);
+void monocle(void);
 void movemouse(Client *c);
 Client *nexttiled(Client *c);
 void propertynotify(XEvent *e);
@@ -1086,7 +1086,7 @@
 }
 
 void
-maximise(void) {
+monocle(void) {
 	Client *c;
 
 	domwfact = dozoom = False;
@@ -44,7 +44,7 @@
  * I intend to not provide real Xinerama support, but instead having a Column
  * tilecols[] array which is used by tile(), and a Column maxcols[] arrays which is used by
- * maximise(). Those arrays should be initialized in config.h. For simplicity
+ * monocle(). Those arrays should be initialized in config.h. For simplicity
  * reasons mwfact should be replaced with a more advanced method which
  * implements the same, but using the boundary between tilecols[0] and